==> QxOrm_1.4.3.zip: QxOrm/include/QxSerialize/QDataStream/QxSerializeQDataStream_std_string.h <==
/****************************************************************************
**
** http://www.qxorm.com/
** Copyright (C) 2013 Lionel Marty (contact@qxorm.com)
**
** This file is part of the QxOrm library
**
** This software is provided 'as-is', without any express or implied
** warranty. In no event will the authors be held liable for any
** damages arising from the use of this software
**
** Commercial Usage
** Licensees holding valid commercial QxOrm licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Lionel Marty
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3.0 as published by the Free Software
** Foundation and appearing in the file 'license.gpl3.txt' included in the
** packaging of this file. Please review the following information to
** ensure the GNU General Public License version 3.0 requirements will be
** met : http://www.gnu.org/copyleft/gpl.html
**
** If you are unsure which license is appropriate for your use, or
** if you have questions regarding the use of this file, please contact :
** contact@qxorm.com
**
****************************************************************************/

#ifndef _QX_SERIALIZE_QDATASTREAM_STD_STRING_H_
#define _QX_SERIALIZE_QDATASTREAM_STD_STRING_H_

#ifdef _MSC_VER
#pragma once
#endif

/*!
 * \file QxSerializeQDataStream_std_string.h
 * \author Lionel Marty
 * \ingroup QxSerialize
 * \brief Provide a Qt QDataStream serialization method (save/load) for type std::string and std::wstring
 */

#include <QtCore/qdatastream.h>

#include <string>

QX_DLL_EXPORT QDataStream & operator<< (QDataStream & stream, const std::string & t) BOOST_USED;
QX_DLL_EXPORT QDataStream & operator>> (QDataStream & stream, std::string & t) BOOST_USED;

QX_DLL_EXPORT QDataStream & operator<< (QDataStream & stream, const std::wstring & t) BOOST_USED;
QX_DLL_EXPORT QDataStream & operator>> (QDataStream & stream, std::wstring & t) BOOST_USED;

#endif // _QX_SERIALIZE_QDATASTREAM_STD_STRING_H_

==> QxOrm_1.4.4.zip: QxOrm/include/QxSerialize/QDataStream/QxSerializeQDataStream_std_string.h <==
/****************************************************************************
**
** http://www.qxorm.com/
** Copyright (C) 2013 Lionel Marty (contact@qxorm.com)
**
** This file is part of the QxOrm library
**
** This software is provided 'as-is', without any express or implied
** warranty. In no event will the authors be held liable for any
** damages arising from the use of this software
**
** Commercial Usage
** Licensees holding valid commercial QxOrm licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Lionel Marty
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3.0 as published by the Free Software
** Foundation and appearing in the file 'license.gpl3.txt' included in the
** packaging of this file. Please review the following information to
** ensure the GNU General Public License version 3.0 requirements will be
** met : http://www.gnu.org/copyleft/gpl.html
**
** If you are unsure which license is appropriate for your use, or
** if you have questions regarding the use of this file, please contact :
** contact@qxorm.com
**
****************************************************************************/

#ifndef _QX_SERIALIZE_QDATASTREAM_STD_STRING_H_
#define _QX_SERIALIZE_QDATASTREAM_STD_STRING_H_

#ifdef _MSC_VER
#pragma once
#endif

/*!
 * \file QxSerializeQDataStream_std_string.h
 * \author Lionel Marty
 * \ingroup QxSerialize
 * \brief Provide a Qt QDataStream serialization method (save/load) for type std::string and std::wstring
 */

#include <QtCore/qdatastream.h>

#include <string>

QX_DLL_EXPORT QDataStream & operator<< (QDataStream & stream, const std::string & t) QX_USED;
QX_DLL_EXPORT QDataStream & operator>> (QDataStream & stream, std::string & t) QX_USED;

QX_DLL_EXPORT QDataStream & operator<< (QDataStream & stream, const std::wstring & t) QX_USED;
QX_DLL_EXPORT QDataStream & operator>> (QDataStream & stream, std::wstring & t) QX_USED;

#endif // _QX_SERIALIZE_QDATASTREAM_STD_STRING_H_
